==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/SpaceSpaceSettingsJupyterServerAppSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property codeRepositories A list of Git repositories that SageMaker automatically displays to users for cloning in the JupyterServer application. see Code Repository below.
 * @property defaultResourceSpec The default instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance. see Default Resource Spec below.
 * @property lifecycleConfigArns The Amazon Resource Name (ARN) of the Lifecycle Configurations.
 */
public data class SpaceSpaceSettingsJupyterServerAppSettings(
    public val codeRepositories: List<SpaceSpaceSettingsJupyterServerAppSettingsCodeRepository>? =
        null,
    public val defaultResourceSpec: SpaceSpaceSettingsJupyterServerAppSettingsDefaultResourceSpec,
    public val lifecycleConfigArns: List<String>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.SpaceSpaceSettingsJupyterServerAppSettings):
            SpaceSpaceSettingsJupyterServerAppSettings = SpaceSpaceSettingsJupyterServerAppSettings(
            codeRepositories = javaType.codeRepositories().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.sagemaker.kotlin.outputs.SpaceSpaceSettingsJupyterServerAppSettingsCodeRepository.Companion.toKotlin(args0)
                })
            }),
            defaultResourceSpec = javaType.defaultResourceSpec().let({ args0 ->
                com.pulumi.aws.sagemaker.kotlin.outputs.SpaceSpaceSettingsJupyterServerAppSettingsDefaultResourceSpec.Companion.toKotlin(args0)
            }),
            lifecycleConfigArns = javaType.lifecycleConfigArns().map({ args0 -> args0 }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/outputs/SpaceSpaceSettingsJupyterServerAppSettings.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property codeRepositories A list of Git repositories that SageMaker automatically displays to users for cloning in the JupyterServer application. See `code_repository` Block below.
 * @property defaultResourceSpec The default instance type and the Amazon Resource Name (ARN) of the SageMaker image created on the instance. See `default_resource_spec` Block below.
 * @property lifecycleConfigArns The Amazon Resource Name (ARN) of the Lifecycle Configurations.
 */
public data class SpaceSpaceSettingsJupyterServerAppSettings(
    public val codeRepositories: List<SpaceSpaceSettingsJupyterServerAppSettingsCodeRepository>? =
        null,
    public val defaultResourceSpec: SpaceSpaceSettingsJupyterServerAppSettingsDefaultResourceSpec,
    public val lifecycleConfigArns: List<String>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.sagemaker.outputs.SpaceSpaceSettingsJupyterServerAppSettings): SpaceSpaceSettingsJupyterServerAppSettings = SpaceSpaceSettingsJupyterServerAppSettings(
            codeRepositories = javaType.codeRepositories().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.sagemaker.kotlin.outputs.SpaceSpaceSettingsJupyterServerAppSettingsCodeRepository.Companion.toKotlin(args0)
                })
            }),
            defaultResourceSpec = javaType.defaultResourceSpec().let({ args0 ->
                com.pulumi.aws.sagemaker.kotlin.outputs.SpaceSpaceSettingsJupyterServerAppSettingsDefaultResourceSpec.Companion.toKotlin(args0)
            }),
            lifecycleConfigArns = javaType.lifecycleConfigArns().map({ args0 -> args0 }),
        )
    }
}
